@@ -254,6 +254,7 @@ get_identity_sync (GoaOAuthProvider  *oauth_provider,
     }
 
  out:
+  g_clear_object (&parser);
   g_clear_error (&identity_error);
   g_clear_object (&call);
   g_clear_object (&proxy);
@@ -392,30 +393,6 @@ build_object (GoaProvider         *provider,
 
 /* ---------------------------------------------------------------------------------------------------- */
 
-static void
-show_account (GoaProvider         *provider,
-              GoaClient           *client,
-              GoaObject           *object,
-              GtkBox              *vbox,
-              GtkGrid             *grid,
-              G_GNUC_UNUSED GtkGrid *dummy)
-{
-  gint row;
-
-  row = 0;
-
-  goa_util_add_account_info (grid, row++, object);
-
-  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
-                                                   /* Translators: This is a label for a series of
-                                                    * options switches. For example: “Use for Mail”. */
-                                                   _("Use for"),
-                                                   "photos-disabled",
-                                                   _("_Photos"));
-}
-
-/* ---------------------------------------------------------------------------------------------------- */
-
 static void
 add_account_key_values (GoaOAuthProvider  *oauth_provider,
                         GVariantBuilder   *builder)
@@ -442,7 +419,6 @@ goa_flickr_provider_class_init (GoaFlickrProviderClass *klass)
   provider_class->get_provider_group         = get_provider_group;
   provider_class->get_provider_features      = get_provider_features;
   provider_class->build_object          = build_object;
-  provider_class->show_account          = show_account;
 
   oauth_class = GOA_OAUTH_PROVIDER_CLASS (klass);
   oauth_class->get_identity_sync        = get_identity_sync;
