@@ -448,7 +448,7 @@ ensure_credentials_sync (GoaProvider         *provider,
                            */
                           _("Invalid %s with username ‘%s’ (%s, %d): "),
                           "smtp-password",
-                          imap_username,
+                          smtp_username,
                           g_quark_to_string ((*error)->domain),
                           (*error)->code);
           (*error)->domain = GOA_ERROR;
@@ -1600,7 +1600,10 @@ on_handle_get_password (GoaPasswordBased      *interface,
   GoaProvider *provider;
   GError *error;
   GVariant *credentials;
+  const gchar *account_id;
   const gchar *identity;
+  const gchar *method_name;
+  const gchar *provider_type;
   gchar *password;
 
   /* TODO: maybe log what app is requesting access */
@@ -1611,7 +1614,13 @@ on_handle_get_password (GoaPasswordBased      *interface,
   object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (interface)));
   account = goa_object_peek_account (object);
   identity = goa_account_get_identity (account);
-  provider = goa_provider_get_for_provider_type (goa_account_get_provider_type (account));
+
+  account_id = goa_account_get_id (account);
+  provider_type = goa_account_get_provider_type (account);
+  method_name = g_dbus_method_invocation_get_method_name (invocation);
+  g_debug ("Handling %s for account (%s, %s)", method_name, provider_type, account_id);
+
+  provider = goa_provider_get_for_provider_type (provider_type);
 
   error = NULL;
   credentials = goa_utils_lookup_credentials_sync (provider,
