@@ -385,11 +385,19 @@ on_handle_get_ticket (GoaTicketing          *interface,
   GoaProvider *provider;
   GError *error;
   gboolean got_ticket;
+  const gchar *id;
+  const gchar *method_name;
+  const gchar *provider_type;
 
   object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (interface)));
   account = goa_object_peek_account (object);
 
-  provider = goa_provider_get_for_provider_type (goa_account_get_provider_type (account));
+  id = goa_account_get_id (account);
+  provider_type = goa_account_get_provider_type (account);
+  method_name = g_dbus_method_invocation_get_method_name (invocation);
+  g_debug ("Handling %s for account (%s, %s)", method_name, provider_type, id);
+
+  provider = goa_provider_get_for_provider_type (provider_type);
   error = NULL;
   got_ticket = get_ticket_sync (GOA_KERBEROS_PROVIDER (provider),
                                 object,
