@@ -75,12 +75,6 @@ struct _GoaProviderClass
                                      GoaObject          *object,
                                      GtkWindow          *parent,
                                      GError            **error);
-  void         (*show_account)      (GoaProvider         *self,
-                                     GoaClient           *client,
-                                     GoaObject           *object,
-                                     GtkBox              *vbox,
-                                     GtkGrid             *grid,
-                                     GtkGrid             *dummy);
   gboolean     (*build_object)      (GoaProvider        *self,
                                      GoaObjectSkeleton  *object,
                                      GKeyFile           *key_file,
@@ -88,21 +82,22 @@ struct _GoaProviderClass
                                      GDBusConnection    *connection,
                                      gboolean            just_added,
                                      GError            **error);
+  GoaProviderGroup     (*get_provider_group)        (GoaProvider   *self);
+  GoaProviderFeatures  (*get_provider_features)     (GoaProvider   *self);
+
   /* virtual but with default implementation */
+  void         (*show_account)      (GoaProvider         *self,
+                                     GoaClient           *client,
+                                     GoaObject           *object,
+                                     GtkBox              *vbox,
+                                     GtkGrid             *grid,
+                                     GtkGrid             *dummy);
   gboolean (*ensure_credentials_sync) (GoaProvider         *self,
                                        GoaObject           *object,
                                        gint                *out_expires_in,
                                        GCancellable        *cancellable,
                                        GError             **error);
   guint    (*get_credentials_generation) (GoaProvider   *self);
-
-  /* pure virtual */
-  GoaProviderGroup (*get_provider_group) (GoaProvider   *self);
-  GoaProviderFeatures  (*get_provider_features)     (GoaProvider   *self);
-
-  /*< private >*/
-  /* Padding for future expansion */
-  gpointer goa_reserved[31];
 };
 
 /**
