@@ -191,7 +191,7 @@ smtp_auth_check_greeting (GDataInputStream *input, GCancellable *cancellable, GE
   ret = FALSE;
 
  greeting_again:
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -219,9 +219,13 @@ static gchar *
 smtp_auth_get_domain (GoaSmtpAuth   *self,
                       GError       **error)
 {
+  GoaMail *mail;
   gchar *domain;
+  gchar *email_address;
 
+  mail = NULL;
   domain = NULL;
+  email_address = NULL;
 
   if (self->domain != NULL)
     {
@@ -229,9 +233,6 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
     }
   else if (self->object != NULL)
     {
-      GoaMail *mail;
-      gchar *email_address;
-
       mail = goa_object_get_mail (self->object);
       if (mail == NULL)
         {
@@ -251,9 +252,6 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
                        _("Failed to parse email address"));
           goto out;
         }
-
-      g_free (email_address);
-      g_object_unref (mail);
     }
   else
     {
@@ -265,6 +263,8 @@ smtp_auth_get_domain (GoaSmtpAuth   *self,
     }
 
  out:
+  g_clear_object (&mail);
+  g_free (email_address);
   return domain;
 }
 
@@ -638,7 +638,7 @@ goa_smtp_auth_run_sync (GoaMailAuth         *auth,
   /* Check which SASL mechanisms are supported */
 
  ehlo_again:
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -706,7 +706,7 @@ goa_smtp_auth_run_sync (GoaMailAuth         *auth,
         goto out;
       g_clear_pointer (&request, g_free);
 
-      response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+      response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
       if (response == NULL)
         goto out;
       g_debug ("< %s", response);
@@ -727,7 +727,7 @@ goa_smtp_auth_run_sync (GoaMailAuth         *auth,
       g_clear_pointer (&request, g_free);
     }
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -793,7 +793,7 @@ goa_smtp_auth_starttls_sync (GoaMailAuth         *auth,
   /* Check if STARTTLS is supported or not */
 
  ehlo_again:
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
@@ -828,7 +828,7 @@ goa_smtp_auth_starttls_sync (GoaMailAuth         *auth,
     goto out;
   g_clear_pointer (&request, g_free);
 
-  response = g_data_input_stream_read_line (input, NULL, cancellable, error);
+  response = goa_utils_data_input_stream_read_line (input, NULL, cancellable, error);
   if (response == NULL)
     goto out;
   g_debug ("< %s", response);
